@@ -1,9 +1,11 @@
-MCS_API = "https://api.multichain.storage/api/"
+MCS_POLYGON_MAIN_API = "https://api.multichain.storage/api/"
+MCS_POLYGON_MUMBAI_API = "https://calibration-mcs-api.filswan.com/api/"
+MCS_BSC_API = 'https://calibration-mcs-bsc.filswan.com/api/'
 REST_API_VERSION = "v1"
 GET = "GET"
 POST = "POST"
 DELETE = "DELETE"
-FIL_PRICE_API = "https://calibration-api.filswan.com/stats/storage"
+FIL_PRICE_API = "https://api.filswan.com/stats/storage"
 # mcs api
 MCS_PARAMS = "/common/system/params"
 PRICE_RATE = "/billing/price/filecoin"
@@ -12,13 +14,11 @@ TASKS_DEALS = "/storage/tasks/deals"
 MINT_INFO = "/storage/mint/info"
 UPLOAD_FILE = "/storage/ipfs/upload"
 DEAL_DETAIL = "/storage/deal/detail/"
+USER_REGISTER = "/user/register"
+USER_LOGIN = "/user/login_by_metamask_signature"
 # contract
-USDC_SPENDER = "0xA1f32c758c4324cC3070A3AA107C4dC7DdFe1a6f"
-USDC_TOKEN = "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174"
 USDC_ABI = "ERC20.json"
-SWAN_PAYMENT_ADDRESS = "0xA1f32c758c4324cC3070A3AA107C4dC7DdFe1a6f"
 SWAN_PAYMENT_ABI = "SwanPayment.json"
-MINT_ADDRESS = "0x7a5FB09Adc5f1bCd7bd1E230Dcc8B6d933c4995E"
-MINT_ABI = "Minter.json"
+MINT_ABI = "SwanNFT.json"
 
 CONTRACT_TIME_OUT = 300
